@@ -20,9 +20,6 @@
 #include <stdio.h>
 
 #include "compiler.h"
-#ifdef HAVE_XAA_H
-#include "xaa.h"
-#endif
 #include "xf86fbman.h"
 #include "exa.h"
 #include "xf86Cursor.h"
@@ -41,11 +38,7 @@
 #define _XF86DRI_SERVER_
 #include "mga_dripriv.h"
 #include "dri.h"
-#include "GL/glxint.h"
 
-#include "dri.h"
-
-#include "GL/glxint.h"
 #include "mga_dri.h"
 #endif
 
@@ -146,6 +139,14 @@ void MGAdbg_outreg32(ScrnInfoPtr, int,int, char*);
 #define PCI_CHIP_MGAG400                0x0525
 #define PCI_CHIP_MGAG550                0x2527
 
+#ifndef PCI_CHIP_MGAG200_EW3_PCI
+#define PCI_CHIP_MGAG200_EW3_PCI 0x0536
+#endif
+
+#ifndef PCI_CHIP_MGAG200_EH3_PCI
+#define PCI_CHIP_MGAG200_EH3_PCI 0x0538
+#endif
+
 /*
  * Read/write to the DAC via MMIO 
  */
@@ -209,15 +210,16 @@ void MGAdbg_outreg32(ScrnInfoPtr, int,int, char*);
 typedef struct {
     unsigned char	ExtVga[6];
     unsigned char 	DacClk[6];
-    unsigned char	ExtVga_Index24;
+    unsigned char	ExtVga_MgaReq;
     unsigned char	Dac_Index90;
-    unsigned char * DacRegs;
+    unsigned char       * DacRegs;
     unsigned long	crtc2[0x58];
     unsigned char	dac2[0x21];
-    CARD32		Option;
-    CARD32		Option2;
-    CARD32		Option3;
+    uint32_t		Option;
+    uint32_t		Option2;
+    uint32_t		Option3;
     long                Clock;
+    unsigned char	Pan_Ctl;
     Bool                PIXPLLCSaved;
     unsigned char       PllM;
     unsigned char       PllN;
@@ -313,16 +315,6 @@ typedef struct {
 #define ISTV1(p) (p->pMgaHwInfo && ((p->pMgaHwInfo->ulCapsFirstOutput) & MGAHWINFOCAPS_OUTPUT_TV))
 #define ISTV2(p) (p->pMgaHwInfo && ((p->pMgaHwInfo->ulCapsSecondOutput) & MGAHWINFOCAPS_OUTPUT_TV))
 
-#ifdef DISABLE_VGA_IO
-typedef struct mgaSave {
-#ifdef XSERVER_LIBPCIACCESS
-    struct pci_device * pvp;
-#else
-    pciVideoPtr pvp;
-#endif
-    Bool enable;
-} MgaSave, *MgaSavePtr;
-#endif
 
 
 typedef enum {
@@ -343,6 +335,13 @@ typedef struct {
     int			mastervideoRam;
     int			slavevideoRam;
     Bool		directRenderingEnabled;
+
+    void *		mappedIOBase;
+    int			mappedIOUsage;
+
+    void *		mappedILOADBase;
+    int			mappedILOADUsage;
+
     ScrnInfoPtr 	pScrn_1;
     ScrnInfoPtr 	pScrn_2;
 } MGAEntRec, *MGAEntPtr;
@@ -385,7 +384,7 @@ typedef enum {
 } mga_host_t;
 
 /**
- * Card information derrived from BIOS PInS data.
+ * Card information derived from BIOS PInS data.
  */
 struct mga_bios_values {
     /**
@@ -428,7 +427,7 @@ struct mga_bios_values {
 
 
 /**
- * Attributes that of an MGA device that can be derrived purely from its
+ * Attributes that of an MGA device that can be derived purely from its
  * PCI ID.
  */
 struct mga_device_attributes {
@@ -519,7 +518,7 @@ typedef struct {
     MessageType		BiosFrom;
 #endif
     unsigned long	FbAddress;
-    unsigned char *     IOBase;
+    void *		IOBase;
     unsigned char *	FbBase;
     unsigned char *	ILOADBase;
     unsigned char *	FbStart;
@@ -557,9 +556,6 @@ typedef struct {
     CARD32		MAccess;
     int			FifoSize;
     int			StyleLen;
-#ifdef HAVE_XAA_H
-    XAAInfoRecPtr	AccelInfoRec;
-#endif
     xf86CursorInfoPtr	CursorInfoRec;
     DGAModePtr		DGAModes;
     int			numDGAModes;
@@ -605,9 +601,6 @@ typedef struct {
     Bool 		directRenderingEnabled;
     DRIInfoPtr 		pDRIInfo;
     int 		drmFD;
-    int 		numVisualConfigs;
-    __GLXvisualConfig*	pVisualConfigs;
-    MGAConfigPrivPtr 	pVisualConfigsPriv;
     MGADRIServerPrivatePtr DRIServerInfo;
 
     MGARegRec		DRContextRegs;
@@ -688,7 +681,12 @@ extern CARD32 MGAAtypeNoBLK[16];
 #define	NICE_DASH_PATTERN	0x00000020
 #define	TWO_PASS_COLOR_EXPAND	0x00000040
 #define	MGA_NO_PLANEMASK	0x00000080
+/* linear expansion doesn't work on BE due to wrong byte order */
+#if X_BYTE_ORDER == X_BIG_ENDIAN
+#define USE_LINEAR_EXPANSION	0x00000000
+#else
 #define USE_LINEAR_EXPANSION	0x00000100
+#endif
 #define LARGE_ADDRESSES		0x00000200
 
 #define MGAIOMAPSIZE		0x00004000
@@ -720,12 +718,10 @@ void MGAAdjustGranularity(ScrnInfoPtr pScrn, int* x, int* y);
 void MGA2064SetupFuncs(ScrnInfoPtr pScrn);
 void MGAGSetupFuncs(ScrnInfoPtr pScrn);
 
-/*#ifdef USE_XAA */
 void MGAStormSync(ScrnInfoPtr pScrn);
 void MGAStormEngineInit(ScrnInfoPtr pScrn);
 Bool MGAStormAccelInit(ScreenPtr pScreen);
 Bool mgaAccelInit(ScreenPtr pScreen);
-/* #endif */
 
 #ifdef USE_EXA
 Bool mgaExaInit(ScreenPtr pScreen);
@@ -733,9 +729,6 @@ Bool mgaExaInit(ScreenPtr pScreen);
 
 Bool MGAHWCursorInit(ScreenPtr pScreen);
 
-
-void MGAPolyArcThinSolid(DrawablePtr, GCPtr, int, xArc*);
-
 Bool MGADGAInit(ScreenPtr pScreen);
 
 void MGARefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
@@ -811,10 +804,6 @@ MGA_MARK_SYNC(MGAPtr pMga, ScrnInfoPtr pScrn)
     if (pMga->Exa)
         exaMarkSync(pScrn->pScreen);
 #endif
-#ifdef USE_XAA
-    if (!pMga->Exa)
-        SET_SYNC_FLAG(pMga->AccelInfoRec);
-#endif
 }
 
 static __inline__ void
@@ -824,10 +813,6 @@ MGA_SYNC(MGAPtr pMga, ScrnInfoPtr pScrn)
     if (pMga->Exa)
         exaWaitSync(pScrn->pScreen);
 #endif
-#ifdef USE_XAA
-    if (!pMga->Exa && pMga->AccelInfoRec && pMga->AccelInfoRec->NeedToSync)
-        pMga->AccelInfoRec->Sync(pScrn);
-#endif
 }
 
 #endif
