@@ -42,9 +42,6 @@
 #include "xf86.h"
 #include "xf86_OSproc.h"
 
-/* Drivers for PCI hardware need this */
-#include "xf86PciInfo.h"
-
 /* Drivers that need to access the PCI config space directly need this */
 #include "xf86Pci.h"
 
@@ -77,7 +74,7 @@ static Bool MGA3026_i2cInit(ScrnInfoPtr pScrn);
 /*
  * indexes to ti3026 registers (the order is important)
  */
-const static unsigned char MGADACregs[] = {
+static const unsigned char MGADACregs[] = {
 	0x0F, 0x18, 0x19, 0x1A, 0x1C,   0x1D, 0x1E, 0x2A, 0x2B, 0x30,
 	0x31, 0x32, 0x33, 0x34, 0x35,   0x36, 0x37, 0x38, 0x39, 0x3A,
 	0x06
@@ -103,12 +100,12 @@ const static unsigned char MGADACregs[] = {
 /*
  * initial values of ti3026 registers
  */
-const static unsigned char MGADACbpp8[DACREGSIZE] = {
+static const unsigned char MGADACbpp8[DACREGSIZE] = {
 	0x06, 0x80, 0x4b, 0x25, 0x00,   0x00, 0x0C, 0x00, 0x1E, 0xFF,
 	0xFF, 0xFF, 0xFF, 0xFF, 0xFF,   0xFF, 0x00, 0x00,    0, 0x00,
 	0x00
 };
-const static unsigned char MGADACbpp16[DACREGSIZE] = {
+static const unsigned char MGADACbpp16[DACREGSIZE] = {
 	0x07, 0x45, 0x53, 0x15, 0x00,   0x00, 0x2C, 0x00, 0x1E, 0xFF,
 	0xFF, 0xFF, 0xFF, 0xFF, 0xFF,   0xFF, 0x00, 0x10,    0, 0x00,
 	0x00
@@ -124,12 +121,12 @@ const static unsigned char MGADACbpp16[DACREGSIZE] = {
    one documented as depending on revision.
  */
 
-const static unsigned char MGADACbpp24[DACREGSIZE] = {
+static const unsigned char MGADACbpp24[DACREGSIZE] = {
 	0x06, 0x56, 0x5b, 0x25, 0x00,   0x00, 0x2C, 0x00, 0x1E, 0xFF,
 	0xFF, 0xFF, 0xFF, 0xFF, 0xFF,   0xFF, 0x00, 0x10,    0, 0x00,
 	0x00
 };
-const static unsigned char MGADACbpp32[DACREGSIZE] = {
+static const unsigned char MGADACbpp32[DACREGSIZE] = {
 	0x07, 0x46, 0x5b, 0x05, 0x00,   0x00, 0x2C, 0x00, 0x1E, 0xFF,
 	0xFF, 0xFF, 0xFF, 0xFF, 0xFF,   0xFF, 0x00, 0x10,    0, 0x00,
 	0x00
@@ -516,7 +513,7 @@ MGA3026Init(ScrnInfoPtr pScrn, DisplayModePtr mode)
 	
 	/* Allocate the DacRegs space if not done already */
 	if (pReg->DacRegs == NULL) {
-		pReg->DacRegs = xnfcalloc(DACREGSIZE, 1);
+		pReg->DacRegs = XNFcallocarray(DACREGSIZE, 1);
 	}
 	for (i = 0; i < DACREGSIZE; i++) {
 	    pReg->DacRegs[i] = initDAC[i]; 
@@ -682,7 +679,7 @@ MGA3026Init(ScrnInfoPtr pScrn, DisplayModePtr mode)
 	  pReg->Option &= ~0x1000;
 
 	/* must always have the pci retries on but rely on 
-	   polling to keep them from occuring */
+	   polling to keep them from occurring */
 	pReg->Option &= ~0x20000000;
 
 	pVga->MiscOutReg |= 0x0C; 
@@ -697,8 +694,8 @@ MGA3026Init(ScrnInfoPtr pScrn, DisplayModePtr mode)
 	MGA_NOT_HAL(MGATi3026SetMCLK(pScrn, MGAdac->MemoryClock));
 
 #ifdef DEBUG		
-	ErrorF("%6ld: %02X %02X %02X	%02X %02X %02X	%08lX\n", mode->Clock,
-		pReg->DacClk[0], pReg->DacClk[1], pReg->DacClk[2], pReg->DacClk[3], pReg->DacClk[4], pReg->DacClk[5], pReg->Option);
+	ErrorF("%6d: %02X %02X %02X	%02X %02X %02X	%08X\n", mode->Clock,
+		pReg->DacClk[0], pReg->DacClk[1], pReg->DacClk[2], pReg->DacClk[3], pReg->DacClk[4], pReg->DacClk[5], (unsigned)pReg->Option);
 	for (i=0; i<sizeof(MGADACregs); i++) ErrorF("%02X ", pReg->DacRegs[i]);
 	for (i=0; i<6; i++) ErrorF(" %02X", pReg->ExtVga[i]);
 	ErrorF("\n");
@@ -814,7 +811,7 @@ MGA3026Save(ScrnInfoPtr pScrn, vgaRegPtr vgaReg, MGARegPtr mgaReg,
 	
 	/* Allocate the DacRegs space if not done already */
 	if (mgaReg->DacRegs == NULL) {
-		mgaReg->DacRegs = xnfcalloc(DACREGSIZE, 1);
+		mgaReg->DacRegs = XNFcallocarray(DACREGSIZE, 1);
 	}
 
 	/*
@@ -855,15 +852,19 @@ MGA3026Save(ScrnInfoPtr pScrn, vgaRegPtr vgaReg, MGARegPtr mgaReg,
 		mgaReg->DacRegs[i]	 = inTi3026(MGADACregs[i]);
 	
 #ifdef XSERVER_LIBPCIACCESS
-	pci_device_cfg_read_u32(pMga->PciInfo, & mgaReg->Option, 
+    {
+	uint32_t Option;
+	pci_device_cfg_read_u32(pMga->PciInfo, & Option,
 				PCI_OPTION_REG);
+        mgaReg->Option = Option;
+    }
 #else
 	mgaReg->Option = pciReadLong(pMga->PciTag, PCI_OPTION_REG);
 #endif
 	
 #ifdef DEBUG		
-	ErrorF("read: %02X %02X %02X	%02X %02X %02X	%08lX\n",
-		mgaReg->DacClk[0], mgaReg->DacClk[1], mgaReg->DacClk[2], mgaReg->DacClk[3], mgaReg->DacClk[4], mgaReg->DacClk[5], mgaReg->Option);
+	ErrorF("read: %02X %02X %02X	%02X %02X %02X	%08X\n",
+		mgaReg->DacClk[0], mgaReg->DacClk[1], mgaReg->DacClk[2], mgaReg->DacClk[3], mgaReg->DacClk[4], mgaReg->DacClk[5], (unsigned)mgaReg->Option);
 	for (i=0; i<sizeof(MGADACregs); i++) ErrorF("%02X ", mgaReg->DacRegs[i]);
 	for (i=0; i<6; i++) ErrorF(" %02X", mgaReg->ExtVga[i]);
 	ErrorF("\n");
