@@ -5,9 +5,6 @@
 #include "xf86.h"
 #include "xf86_OSproc.h"
 #include "xf86Pci.h"
-#include "xf86PciInfo.h"
-#include "xaa.h"
-#include "xaalocal.h"
 #include "mga.h"
 #include "mga_reg.h"
 #include "dgaproc.h"
@@ -18,10 +15,6 @@ static Bool MGA_OpenFramebuffer(ScrnInfoPtr, char **, unsigned char **,
 static Bool MGA_SetMode(ScrnInfoPtr, DGAModePtr);
 static int  MGA_GetViewport(ScrnInfoPtr);
 static void MGA_SetViewport(ScrnInfoPtr, int, int, int);
-static void MGA_FillRect(ScrnInfoPtr, int, int, int, int, unsigned long);
-static void MGA_BlitRect(ScrnInfoPtr, int, int, int, int, int, int);
-static void MGA_BlitTransRect(ScrnInfoPtr, int, int, int, int, int, int, 
-					unsigned long);
 
 static
 DGAFunctionRec MGA_DGAFuncs = {
@@ -31,9 +24,7 @@ DGAFunctionRec MGA_DGAFuncs = {
    MGA_SetViewport,
    MGA_GetViewport,
    MGAStormSync,
-   MGA_FillRect,
-   MGA_BlitRect,
-   MGA_BlitTransRect
+   NULL, NULL, NULL
 };
 
 
@@ -121,11 +112,6 @@ SECOND_PASS:
 	    mode->flags = DGA_CONCURRENT_ACCESS;
             if(pixmap)
 		mode->flags |= DGA_PIXMAP_AVAILABLE;
-	    if(!pMga->NoAccel) {
-		mode->flags |= DGA_FILL_RECT | DGA_BLIT_RECT;
-		if((Bpp != 3) && (pMga->Chipset != PCI_CHIP_MGA2064))
-		    mode->flags |= DGA_BLIT_RECT_TRANS;
-	    }
 	    if(pMode->Flags & V_DBLSCAN)
 		mode->flags |= DGA_DOUBLESCAN;
 	    if(pMode->Flags & V_INTERLACE)
@@ -198,7 +184,7 @@ SECOND_PASS:
 Bool
 MGADGAInit(ScreenPtr pScreen)
 {   
-   ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+   ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
    MGAPtr pMga = MGAPTR(pScrn);
    DGAModePtr modes = NULL;
    int num = 0;
@@ -311,8 +297,8 @@ MGA_SetMode(
         memcpy(&pMga->CurrentLayout, &SavedLayouts[index], sizeof(MGAFBLayout));
                 
       pScrn->currentMode = pMga->CurrentLayout.mode;
-      pScrn->SwitchMode(index, pScrn->currentMode, 0);
-      MGAAdjustFrame(index, pScrn->frameX0, pScrn->frameY0, 0);
+      pScrn->SwitchMode(SWITCH_MODE_ARGS(pScrn, pScrn->currentMode));
+      MGAAdjustFrame(ADJUST_FRAME_ARGS(pScrn, pScrn->frameX0, pScrn->frameY0));
       pMga->DGAactive = FALSE;
    } else {
       if(!pMga->DGAactive) {  /* save the old parameters */
@@ -329,7 +315,7 @@ MGA_SetMode(
       pMga->CurrentLayout.weight.blue = BitsSet(pMode->blue_mask);
       /* MGAModeInit() will set the mode field */
 
-      pScrn->SwitchMode(index, pMode->mode, 0);
+      pScrn->SwitchMode(SWITCH_MODE_ARGS(pScrn, pMode->mode));
       /* not strictly required but nice */
       mgaDGASetPalette(pScrn);
    }
@@ -356,77 +342,10 @@ MGA_SetViewport(
 ){
    MGAPtr pMga = MGAPTR(pScrn);
 
-   MGAAdjustFrame(pScrn->pScreen->myNum, x, y, flags);
+   MGAAdjustFrame(ADJUST_FRAME_ARGS(pScrn, x, y));
    pMga->DGAViewportStatus = 0;  /* MGAAdjustFrame loops until finished */
 }
 
-static void 
-MGA_FillRect (
-   ScrnInfoPtr pScrn, 
-   int x, int y, int w, int h, 
-   unsigned long color
-){
-    MGAPtr pMga = MGAPTR(pScrn);
-
-    if(!pMga->AccelInfoRec) return;
-
-    mgaDoSetupForSolidFill(pScrn, color, GXcopy, ~0, 
-			   pMga->CurrentLayout.bitsPerPixel);
-    (*pMga->AccelInfoRec->SubsequentSolidFillRect)(pScrn, x, y, w, h);
-
-    SET_SYNC_FLAG(pMga->AccelInfoRec);
-}
-
-static void 
-MGA_BlitRect(
-   ScrnInfoPtr pScrn, 
-   int srcx, int srcy, 
-   int w, int h, 
-   int dstx, int dsty
-){
-    MGAPtr pMga = MGAPTR(pScrn);
-    int xdir = ((srcx < dstx) && (srcy == dsty)) ? -1 : 1;
-    int ydir = (srcy < dsty) ? -1 : 1;
-
-    if(!pMga->AccelInfoRec) return;
-
-    mgaDoSetupForScreenToScreenCopy( pScrn, xdir, ydir, GXcopy, ~0, -1,
-				     pMga->CurrentLayout.bitsPerPixel );
-
-    (*pMga->AccelInfoRec->SubsequentScreenToScreenCopy)(
-		pScrn, srcx, srcy, dstx, dsty, w, h);
-
-    SET_SYNC_FLAG(pMga->AccelInfoRec);
-}
-
-
-static void MGA_BlitTransRect( ScrnInfoPtr pScrn, int srcx, int srcy, 
-			       int w, int h, int dstx, int dsty,
-			       unsigned long color )
-{
-    MGAPtr pMga = MGAPTR(pScrn);
-
-    if( (pMga->AccelInfoRec != NULL)
-	&& (pMga->CurrentLayout.bitsPerPixel != 24)
-	&& (pMga->Chipset != PCI_CHIP_MGA2064) ) {
-	const int xdir = ((srcx < dstx) && (srcy == dsty)) ? -1 : 1;
-	const int ydir = (srcy < dsty) ? -1 : 1;
-
-	pMga->DrawTransparent = TRUE;
-
-	mgaDoSetupForScreenToScreenCopy( pScrn, xdir, ydir, GXcopy, ~0, color,
-					 pMga->CurrentLayout.bitsPerPixel );
-
-	pMga->DrawTransparent = FALSE;
-
-	(*pMga->AccelInfoRec->SubsequentScreenToScreenCopy)(
-	    pScrn, srcx, srcy, dstx, dsty, w, h);
-
-	SET_SYNC_FLAG(pMga->AccelInfoRec);
-    }
-}
-
-
 static Bool 
 MGA_OpenFramebuffer(
    ScrnInfoPtr pScrn, 
