@@ -48,15 +48,8 @@
 #include "mga_drm.h"
 
 #define _XF86DRI_SERVER_
-#include "GL/glxtokens.h"
 #include "sarea.h"
 
-
-
-
-
-#include "GL/glxtokens.h"
-
 #include "mga_reg.h"
 #include "mga.h"
 #include "mga_macros.h"
@@ -67,224 +60,6 @@
 static char MGAKernelDriverName[] = "mga";
 static char MGAClientDriverName[] = "mga";
 
-/* Initialize the visual configs that are supported by the hardware.
- * These are combined with the visual configs that the indirect
- * rendering core supports, and the intersection is exported to the
- * client.
- */
-static Bool MGAInitVisualConfigs( ScreenPtr pScreen )
-{
-   ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
-   MGAPtr pMga = MGAPTR(pScrn);
-   int numConfigs = 0;
-   __GLXvisualConfig *pConfigs = 0;
-   MGAConfigPrivPtr pMGAConfigs = 0;
-   MGAConfigPrivPtr *pMGAConfigPtrs = 0;
-   int i, db, depth, stencil, accum;
-
-   switch ( pScrn->bitsPerPixel ) {
-   case 8:
-   case 24:
-      break;
-
-   case 16:
-      numConfigs = 8;
-
-      pConfigs = (__GLXvisualConfig*)calloc( sizeof(__GLXvisualConfig),
-						numConfigs );
-      if ( !pConfigs ) {
-	 return FALSE;
-      }
-
-      pMGAConfigs = (MGAConfigPrivPtr)calloc( sizeof(MGAConfigPrivRec),
-						 numConfigs );
-      if ( !pMGAConfigs ) {
-	 free(pConfigs);
-	 return FALSE;
-      }
-
-      pMGAConfigPtrs = (MGAConfigPrivPtr*)calloc( sizeof(MGAConfigPrivPtr),
-						     numConfigs );
-      if ( !pMGAConfigPtrs ) {
-	 free(pConfigs);
-	 free(pMGAConfigs);
-	 return FALSE;
-      }
-
-      for ( i = 0 ; i < numConfigs ; i++ ) {
-	 pMGAConfigPtrs[i] = &pMGAConfigs[i];
-      }
-
-      i = 0;
-      for ( accum = 0 ; accum <= 1 ; accum++ ) {
-         for ( stencil = 0 ; stencil <= 1 ; stencil++ ) {
-            for ( db = 1 ; db >= 0 ; db-- ) {
-               pConfigs[i].vid			= -1;
-               pConfigs[i].class		= -1;
-               pConfigs[i].rgba			= TRUE;
-               pConfigs[i].redSize		= 5;
-               pConfigs[i].greenSize		= 6;
-               pConfigs[i].blueSize		= 5;
-               pConfigs[i].alphaSize		= 0;
-               pConfigs[i].redMask		= 0x0000F800;
-               pConfigs[i].greenMask		= 0x000007E0;
-               pConfigs[i].blueMask		= 0x0000001F;
-               pConfigs[i].alphaMask		= 0;
-               if ( accum ) {
-                  pConfigs[i].accumRedSize	= 16;
-                  pConfigs[i].accumGreenSize	= 16;
-                  pConfigs[i].accumBlueSize	= 16;
-                  pConfigs[i].accumAlphaSize	= 0;
-               } else {
-                  pConfigs[i].accumRedSize	= 0;
-                  pConfigs[i].accumGreenSize	= 0;
-                  pConfigs[i].accumBlueSize	= 0;
-                  pConfigs[i].accumAlphaSize	= 0;
-               }
-               if ( db ) {
-                  pConfigs[i].doubleBuffer	= TRUE;
-               } else {
-                  pConfigs[i].doubleBuffer	= FALSE;
-	       }
-               pConfigs[i].stereo		= FALSE;
-               pConfigs[i].bufferSize		= 16;
-               pConfigs[i].depthSize		= 16;
-               if ( stencil ) {
-                  pConfigs[i].stencilSize	= 8;
-               } else {
-                  pConfigs[i].stencilSize	= 0;
-	       }
-               pConfigs[i].auxBuffers		= 0;
-               pConfigs[i].level		= 0;
-               if ( accum || stencil ) {
-                  pConfigs[i].visualRating	= GLX_SLOW_CONFIG;
-               } else {
-                  pConfigs[i].visualRating	= GLX_NONE;
-	       }
-               pConfigs[i].transparentPixel	= GLX_NONE;
-               pConfigs[i].transparentRed	= 0;
-               pConfigs[i].transparentGreen	= 0;
-               pConfigs[i].transparentBlue	= 0;
-               pConfigs[i].transparentAlpha	= 0;
-               pConfigs[i].transparentIndex	= 0;
-               i++;
-            }
-         }
-      }
-      if ( i != numConfigs ) {
-         xf86DrvMsg( pScrn->scrnIndex, X_ERROR,
-		     "[drm] Incorrect initialization of visuals\n" );
-         return FALSE;
-      }
-      break;
-
-   case 32:
-      numConfigs = 8;
-
-      pConfigs = (__GLXvisualConfig*)calloc( sizeof(__GLXvisualConfig),
-						numConfigs );
-      if ( !pConfigs ) {
-	 return FALSE;
-      }
-
-      pMGAConfigs = (MGAConfigPrivPtr)calloc( sizeof(MGAConfigPrivRec),
-						 numConfigs );
-      if ( !pMGAConfigs ) {
-	 free(pConfigs);
-	 return FALSE;
-      }
-
-      pMGAConfigPtrs = (MGAConfigPrivPtr*)calloc( sizeof(MGAConfigPrivPtr),
-						     numConfigs );
-      if ( !pMGAConfigPtrs ) {
-	 free(pConfigs);
-	 free(pMGAConfigs);
-	 return FALSE;
-      }
-
-      for ( i = 0 ; i < numConfigs ; i++ ) {
-	 pMGAConfigPtrs[i] = &pMGAConfigs[i];
-      }
-
-      i = 0;
-      for ( accum = 0 ; accum <= 1 ; accum++ ) {
-         for ( depth = 0 ; depth <= 1 ; depth++ ) { /* and stencil */
-            for ( db = 1 ; db >= 0 ; db-- ) {
-               pConfigs[i].vid			= -1;
-               pConfigs[i].class		= -1;
-               pConfigs[i].rgba			= TRUE;
-               pConfigs[i].redSize		= 8;
-               pConfigs[i].greenSize		= 8;
-               pConfigs[i].blueSize		= 8;
-               pConfigs[i].alphaSize		= 0;
-               pConfigs[i].redMask		= 0x00FF0000;
-               pConfigs[i].greenMask		= 0x0000FF00;
-               pConfigs[i].blueMask		= 0x000000FF;
-               pConfigs[i].alphaMask		= 0x0;
-               if ( accum ) {
-                  pConfigs[i].accumRedSize	= 16;
-                  pConfigs[i].accumGreenSize	= 16;
-                  pConfigs[i].accumBlueSize	= 16;
-                  pConfigs[i].accumAlphaSize	= 0;
-               } else {
-                  pConfigs[i].accumRedSize	= 0;
-                  pConfigs[i].accumGreenSize	= 0;
-                  pConfigs[i].accumBlueSize	= 0;
-                  pConfigs[i].accumAlphaSize	= 0;
-               }
-               if ( db ) {
-                  pConfigs[i].doubleBuffer	= TRUE;
-               } else {
-                  pConfigs[i].doubleBuffer	= FALSE;
-	       }
-               pConfigs[i].stereo		= FALSE;
-               pConfigs[i].bufferSize		= 24;
-               if ( depth ) {
-		     pConfigs[i].depthSize	= 24;
-                     pConfigs[i].stencilSize	= 8;
-               }
-               else {
-                     pConfigs[i].depthSize	= 0;
-                     pConfigs[i].stencilSize	= 0;
-               }
-               pConfigs[i].auxBuffers		= 0;
-               pConfigs[i].level		= 0;
-               if ( accum ) {
-                  pConfigs[i].visualRating	= GLX_SLOW_CONFIG;
-               } else {
-                  pConfigs[i].visualRating	= GLX_NONE;
-	       }
-               pConfigs[i].transparentPixel	= GLX_NONE;
-               pConfigs[i].transparentRed	= 0;
-               pConfigs[i].transparentGreen	= 0;
-               pConfigs[i].transparentBlue	= 0;
-               pConfigs[i].transparentAlpha	= 0;
-               pConfigs[i].transparentIndex	= 0;
-               i++;
-            }
-         }
-      }
-      if ( i != numConfigs ) {
-         xf86DrvMsg( pScrn->scrnIndex, X_ERROR,
-		     "[drm] Incorrect initialization of visuals\n" );
-         return FALSE;
-      }
-      break;
-
-   default:
-      /* Unexpected bits/pixels */
-      break;
-   }
-
-   pMga->numVisualConfigs = numConfigs;
-   pMga->pVisualConfigs = pConfigs;
-   pMga->pVisualConfigsPriv = pMGAConfigs;
-
-   GlxSetVisualConfigs( numConfigs, pConfigs, (void **)pMGAConfigPtrs );
-
-   return TRUE;
-}
-
 static Bool MGACreateContext( ScreenPtr pScreen, VisualPtr visual,
 			      drm_context_t hwContext, void *pVisualConfigPriv,
 			      DRIContextType contextStore )
@@ -350,36 +125,9 @@ void MGAGetQuiescence( ScrnInfoPtr pScrn )
    pMga->haveQuiescense = 1;
 
    if ( pMga->directRenderingEnabled ) {
-      MGAFBLayout *pLayout = &pMga->CurrentLayout;
-
       MGAWaitForIdleDMA( pScrn );
 
         /* FIXME what about EXA? */
-#ifdef XAA
-        if (!pMga->Exa && pMga->AccelInfoRec) {
-      WAITFIFO( 11 );
-      OUTREG( MGAREG_MACCESS, pMga->MAccess );
-      OUTREG( MGAREG_PITCH, pLayout->displayWidth );
-
-      pMga->PlaneMask = ~0;
-      OUTREG( MGAREG_PLNWT, pMga->PlaneMask );
-
-      pMga->BgColor = 0;
-      pMga->FgColor = 0;
-      OUTREG( MGAREG_BCOL, pMga->BgColor );
-      OUTREG( MGAREG_FCOL, pMga->FgColor );
-      OUTREG( MGAREG_SRCORG, pMga->realSrcOrg );
-
-      pMga->SrcOrg = 0;
-      OUTREG( MGAREG_DSTORG, pMga->DstOrg );
-      OUTREG( MGAREG_OPMODE, MGAOPM_DMA_BLIT );
-      OUTREG( MGAREG_CXBNDRY, 0xFFFF0000 ); /* (maxX << 16) | minX */
-      OUTREG( MGAREG_YTOP, 0x00000000 );    /* minPixelPointer */
-      OUTREG( MGAREG_YBOT, 0x007FFFFF );    /* maxPixelPointer */
-
-            pMga->AccelFlags &= ~CLIPPER_ON;
-        }
-#endif
    }
 }
 
@@ -397,10 +145,6 @@ void MGAGetQuiescenceShared( ScrnInfoPtr pScrn )
       MGAWaitForIdleDMA( pMGAEnt->pScrn_1 );
 
         /* FIXME what about EXA? */
-#ifdef USE_XAA
-        if (!pMga->Exa && pMga->AccelInfoRec)
-            pMga->RestoreAccelState( pScrn );
-#endif
       xf86SetLastScrnFlag( pScrn->entityList[0], pScrn->scrnIndex );
    }
 }
@@ -440,7 +184,7 @@ static void MGASwapContextShared( ScreenPtr pScreen )
  * This is really only called from validate/postvalidate as we
  * override the dri lock/unlock.  Want to remove validate/postvalidate
  * processing, but need to remove all client-side use of drawable lock
- * first (otherwise there is noone recover when a client dies holding
+ * first (otherwise there is no one recover when a client dies holding
  * the drawable lock).
  *
  * What does this mean?
@@ -891,191 +635,12 @@ static Bool MGADRIBuffersInit( ScreenPtr pScreen )
     return TRUE;
 }
 
-#ifdef USE_XAA
-static void MGADRIInitBuffersXAA(WindowPtr pWin, RegionPtr prgn,
-                                 CARD32 index)
-{
-    ScreenPtr pScreen = pWin->drawable.pScreen;
-    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
-    MGAPtr pMga = MGAPTR(pScrn);
-    BoxPtr pbox = REGION_RECTS(prgn);
-    int nbox  = REGION_NUM_RECTS(prgn);
-    XAAInfoRecPtr xaa = pMga->AccelInfoRec;
-
-    CHECK_DMA_QUIESCENT(MGAPTR(pScrn), pScrn);
-
-    xaa->SetupForSolidFill(pScrn, 0, GXcopy, -1);
-
-    while (nbox--) {
-        MGASelectBuffer(pScrn, MGA_BACK);
-        xaa->SubsequentSolidFillRect(pScrn, pbox->x1, pbox->y1,
-                                     pbox->x2-pbox->x1, pbox->y2-pbox->y1);
-        MGASelectBuffer(pScrn, MGA_DEPTH);
-        xaa->SubsequentSolidFillRect(pScrn, pbox->x1, pbox->y1,
-                                     pbox->x2-pbox->x1, pbox->y2-pbox->y1);
-        pbox++;
-    }
-
-    MGASelectBuffer(pScrn, MGA_FRONT);
-
-    pMga->AccelInfoRec->NeedToSync = TRUE;
-}
-#endif
-
 static void MGADRIInitBuffersEXA(WindowPtr pWin, RegionPtr prgn,
                                  CARD32 index)
 {
     /* FIXME */
 }
 
-#ifdef USE_XAA
-/*
-  This routine is a modified form of XAADoBitBlt with the calls to
-  ScreenToScreenBitBlt built in. My routine has the prgnSrc as source
-  instead of destination. My origin is upside down so the ydir cases
-  are reversed.
-*/
-static void MGADRIMoveBuffersXAA(WindowPtr pParent, DDXPointRec ptOldOrg,
-                                 RegionPtr prgnSrc, CARD32 index)
-{
-    ScreenPtr pScreen = pParent->drawable.pScreen;
-    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
-    MGAPtr pMga = MGAPTR(pScrn);
-    int nbox;
-    BoxPtr pbox, pboxTmp, pboxNext, pboxBase, pboxNew1, pboxNew2;
-    DDXPointPtr pptTmp, pptNew1, pptNew2;
-    int xdir, ydir;
-    int dx, dy;
-    DDXPointPtr pptSrc;
-    int screenwidth = pScrn->virtualX;
-    int screenheight = pScrn->virtualY;
-    XAAInfoRecPtr xaa = pMga->AccelInfoRec;
-
-    CHECK_DMA_QUIESCENT(pMga, pScrn);
-
-    pbox = REGION_RECTS(prgnSrc);
-    nbox = REGION_NUM_RECTS(prgnSrc);
-    pboxNew1 = 0;
-    pptNew1 = 0;
-    pboxNew2 = 0;
-    pboxNew2 = 0;
-    pptSrc = &ptOldOrg;
-
-    dx = pParent->drawable.x - ptOldOrg.x;
-    dy = pParent->drawable.y - ptOldOrg.y;
-
-    /* If the copy will overlap in Y, reverse the order */
-    if (dy>0) {
-        ydir = -1;
-
-        if (nbox>1) {
-	    /* Keep ordering in each band, reverse order of bands */
-	    pboxNew1 = (BoxPtr)malloc(sizeof(BoxRec)*nbox);
-	    if (!pboxNew1) return;
-	    pptNew1 = (DDXPointPtr)malloc(sizeof(DDXPointRec)*nbox);
-	    if (!pptNew1) {
-	        free(pboxNew1);
-	        return;
-	    }
-	    pboxBase = pboxNext = pbox+nbox-1;
-	    while (pboxBase >= pbox) {
-	        while ((pboxNext >= pbox) && (pboxBase->y1 == pboxNext->y1))
-		  pboxNext--;
-	        pboxTmp = pboxNext+1;
-	        pptTmp = pptSrc + (pboxTmp - pbox);
-	        while (pboxTmp <= pboxBase) {
-		    *pboxNew1++ = *pboxTmp++;
-		    *pptNew1++ = *pptTmp++;
-		}
-	        pboxBase = pboxNext;
-	    }
-	    pboxNew1 -= nbox;
-	    pbox = pboxNew1;
-	    pptNew1 -= nbox;
-	    pptSrc = pptNew1;
-	}
-    } else {
-        /* No changes required */
-        ydir = 1;
-    }
-
-    /* If the regions will overlap in X, reverse the order */
-    if (dx>0) {
-        xdir = -1;
-
-        if (nbox > 1) {
-	    /*reverse orderof rects in each band */
-	    pboxNew2 = (BoxPtr)malloc(sizeof(BoxRec)*nbox);
-	    pptNew2 = (DDXPointPtr)malloc(sizeof(DDXPointRec)*nbox);
-	    if (!pboxNew2 || !pptNew2) {
-	        free(pptNew2);
-	        free(pboxNew2);
-	        if (pboxNew1) {
-		    free(pptNew1);
-		    free(pboxNew1);
-		}
-	       return;
-	    }
-	    pboxBase = pboxNext = pbox;
-	    while (pboxBase < pbox+nbox) {
-	        while ((pboxNext < pbox+nbox) &&
-		       (pboxNext->y1 == pboxBase->y1))
-		  pboxNext++;
-	        pboxTmp = pboxNext;
-	        pptTmp = pptSrc + (pboxTmp - pbox);
-	        while (pboxTmp != pboxBase) {
-		    *pboxNew2++ = *--pboxTmp;
-		    *pptNew2++ = *--pptTmp;
-		}
-	        pboxBase = pboxNext;
-	    }
-	    pboxNew2 -= nbox;
-	    pbox = pboxNew2;
-	    pptNew2 -= nbox;
-	    pptSrc = pptNew2;
-	}
-    } else {
-        /* No changes are needed */
-        xdir = 1;
-    }
-
-    xaa->SetupForScreenToScreenCopy(pScrn, xdir, ydir, GXcopy, -1, -1);
-    for ( ; nbox-- ; pbox++) {
-	 int x1 = pbox->x1;
-	 int y1 = pbox->y1;
-	 int destx = x1 + dx;
-	 int desty = y1 + dy;
-	 int w = pbox->x2 - x1 + 1;
-	 int h = pbox->y2 - y1 + 1;
-
-	 if ( destx < 0 ) x1 -= destx, w += destx, destx = 0;
-	 if ( desty < 0 ) y1 -= desty, h += desty, desty = 0;
-	 if ( destx + w > screenwidth ) w = screenwidth - destx;
-	 if ( desty + h > screenheight ) h = screenheight - desty;
-	 if ( w <= 0 ) continue;
-	 if ( h <= 0 ) continue;
-
-	 MGASelectBuffer(pScrn, MGA_BACK);
-	 xaa->SubsequentScreenToScreenCopy(pScrn, x1, y1, destx, desty, w, h);
-	 MGASelectBuffer(pScrn, MGA_DEPTH);
-	 xaa->SubsequentScreenToScreenCopy(pScrn, x1, y1, destx, desty, w, h);
-    }
-    MGASelectBuffer(pScrn, MGA_FRONT);
-
-    if (pboxNew2) {
-        free(pptNew2);
-        free(pboxNew2);
-    }
-    if (pboxNew1) {
-        free(pptNew1);
-        free(pboxNew1);
-    }
-
-    pMga->AccelInfoRec->NeedToSync = TRUE;
-
-}
-#endif
-
 static void MGADRIMoveBuffersEXA(WindowPtr pParent, DDXPointRec ptOldOrg,
                                  RegionPtr prgnSrc, CARD32 index)
 {
@@ -1095,10 +660,9 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
        return FALSE;
    }
 
-   /* Check that the GLX, DRI, and DRM modules have been loaded by testing
+   /* Check that the DRI, and DRM modules have been loaded by testing
     * for canonical symbols in each module.
     */
-   if ( !xf86LoaderCheckSymbol( "GlxSetVisualConfigs" ) )	return FALSE;
    if ( !xf86LoaderCheckSymbol( "drmAvailable" ) )		return FALSE;
    if ( !xf86LoaderCheckSymbol( "DRIQueryVersion" ) ) {
       xf86DrvMsg( pScreen->myNum, X_ERROR,
@@ -1165,9 +729,6 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
    pDRIInfo->frameBufferStride = pScrn->displayWidth*(pScrn->bitsPerPixel/8);
    pDRIInfo->ddxDrawableTableEntry = MGA_MAX_DRAWABLES;
 
-   pDRIInfo->wrap.ValidateTree = NULL;
-   pDRIInfo->wrap.PostValidateTree = NULL;
-
    pDRIInfo->createDummyCtx = TRUE;
    pDRIInfo->createDummyCtxPriv = FALSE;
 
@@ -1193,7 +754,7 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
 
    pDRIInfo->SAREASize = SAREA_MAX;
 
-   pMGADRI = (MGADRIPtr)calloc( sizeof(MGADRIRec), 1 );
+   pMGADRI = (MGADRIPtr)calloc( 1, sizeof(MGADRIRec) );
    if ( !pMGADRI ) {
       DRIDestroyInfoRec( pMga->pDRIInfo );
       pMga->pDRIInfo = 0;
@@ -1203,7 +764,7 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
    }
 
    pMGADRIServer = (MGADRIServerPrivatePtr)
-      calloc( sizeof(MGADRIServerPrivateRec), 1 );
+      calloc( 1, sizeof(MGADRIServerPrivateRec) );
    if ( !pMGADRIServer ) {
       free( pMGADRI );
       DRIDestroyInfoRec( pMga->pDRIInfo );
@@ -1229,19 +790,6 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
 
    pDRIInfo->InitBuffers = MGADRIInitBuffersEXA;
    pDRIInfo->MoveBuffers = MGADRIMoveBuffersEXA;
-#ifdef USE_EXA
-    if (pMga->Exa) {
-        pDRIInfo->InitBuffers = MGADRIInitBuffersEXA;
-        pDRIInfo->MoveBuffers = MGADRIMoveBuffersEXA;
-    } else {
-#endif
-#ifdef USE_XAA
-        pDRIInfo->InitBuffers = MGADRIInitBuffersXAA;
-        pDRIInfo->MoveBuffers = MGADRIMoveBuffersXAA;
-#endif
-#ifdef USE_EXA
-    }
-#endif
 
    pDRIInfo->bufferRequests = DRI_ALL_WINDOWS;
 
@@ -1353,10 +901,6 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
 			&scratch_ptr);
    }
 
-   if ( !MGAInitVisualConfigs( pScreen ) ) {
-      DRICloseScreen( pScreen );
-      return FALSE;
-   }
    xf86DrvMsg( pScrn->scrnIndex, X_INFO, "[dri] visual configs initialized\n" );
 
    return TRUE;
@@ -1498,6 +1042,4 @@ void MGADRICloseScreen( ScreenPtr pScreen )
    }
    free(pMga->DRIServerInfo);
    pMga->DRIServerInfo = 0;
-   free(pMga->pVisualConfigs);
-   free(pMga->pVisualConfigsPriv);
 }
