@@ -10,8 +10,6 @@
 
 #include "compiler.h"
 
-/* Drivers for PCI hardware need this */
-#include "xf86PciInfo.h"
 #include "mga.h"
 #include "mga_macros.h"
 #include "mga_reg.h"
@@ -20,12 +18,12 @@
 #include "fbdevhw.h"
 
 static int
-StrToRanges(range* r, char* s) {
+StrToRanges(range* r, const char* s) {
     float num=0.0;
     int rangenum=0;
     Bool gotdash = FALSE;
     Bool nextdash = FALSE;
-    char* strnum=NULL;
+    const char* strnum=NULL;
     do {
         switch(*s) {
             case '0': case '1': case '2': case '3': case '4': case '5':
@@ -39,7 +37,7 @@ StrToRanges(range* r, char* s) {
                 break;
             case '-':
             case ' ': case 0:
-                if(strnum == NULL) break; /*is extra seperator */
+                if(strnum == NULL) break; /*is extra separator */
                 if(strnum != NULL) sscanf(strnum,"%f",&num);
                 if(gotdash) /*if wasn't singlet: correct. */
                     r[rangenum-1].hi = num;
@@ -61,7 +59,7 @@ StrToRanges(range* r, char* s) {
 }            
 
 
-/* Copys mode i, links the result to dest, and returns it.
+/* Copies mode i, links the result to dest, and returns it.
  * Links i and j in Private record.
  * if dest is NULL, return value is copy of i linked to itself.
  */
@@ -119,7 +117,7 @@ CopyModeNLink(ScrnInfoPtr pScrn, DisplayModePtr dest, DisplayModePtr i, DisplayM
 }
 
 static DisplayModePtr
-GetModeFromName(char* str, DisplayModePtr i)
+GetModeFromName(const char* str, DisplayModePtr i)
 {
     DisplayModePtr c = i;
     if(!i) return NULL;
@@ -132,9 +130,9 @@ GetModeFromName(char* str, DisplayModePtr i)
 
 /* takes a config file string of MetaModes and generates a MetaModeList */
 static DisplayModePtr
-GenerateModeList(ScrnInfoPtr pScrn, char* str,
+GenerateModeList(ScrnInfoPtr pScrn, const char* str,
 		 DisplayModePtr i, DisplayModePtr j, MgaScrn2Rel srel) {
-    char* strmode = str;
+    const char* strmode = str;
     char modename[256];
     Bool gotdash = FALSE;
     MgaScrn2Rel sr;
@@ -167,7 +165,7 @@ GenerateModeList(ScrnInfoPtr pScrn, char* str,
                     } else {
                         mode1 = GetModeFromName(modename,i);
                         if(!mode1) {
-                            char* tmps = str;
+                            const char* tmps = str;
                             xf86DrvMsg(pScrn->scrnIndex, X_CONFIG,
                                 "Mode: \"%s\" is not a supported mode for monitor 1\n",modename);
                             /* find if a monitor2 mode follows */
@@ -192,7 +190,7 @@ GenerateModeList(ScrnInfoPtr pScrn, char* str,
                 strmode = str+1; /* number starts on next char */
                 gotdash |= (*str == '-' || *str == ',');
                 
-                if(*str != 0) break; /* if end of string, we wont get a chance to catch a char and run the
+                if(*str != 0) break; /* if end of string, we won't get a chance to catch a char and run the
                                         default case. do it now */
                 
             default:
@@ -222,7 +220,7 @@ GenerateModeList(ScrnInfoPtr pScrn, char* str,
 }
     
 
-/* second CRTC init funcitons. Used to check monitor timings and refreshes. 
+/* second CRTC init functions. Used to check monitor timings and refreshes.
  * this function looses lots of maintainability points due to redundancy, 
  * but it still was the cleanest and least-intrusive way I found. */
 
@@ -234,7 +232,7 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     MGAPtr pMga1;
     MessageType from;
     int i;
-    char* s;
+    const char* s;
     ClockRangePtr clockRanges;
     MgaScrn2Rel Monitor2Pos;
 
@@ -259,7 +257,7 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     pMga->device = pMga1->device;
     
     if (flags & PROBE_DETECT) {
-	MGAProbeDDC(pScrn, pMga->pEnt->index); /*FIXME make shure this probes second monitor */
+	MGAProbeDDC(pScrn, pMga->pEnt->index); /*FIXME make sure this probes second monitor */
 	return TRUE;
     }
 
@@ -355,9 +353,11 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     case PCI_CHIP_MGAG200_SE_A_PCI:
     case PCI_CHIP_MGAG200_SE_B_PCI:
     case PCI_CHIP_MGAG200_WINBOND_PCI:
+    case PCI_CHIP_MGAG200_EW3_PCI:
     case PCI_CHIP_MGAG200_EV_PCI:
     case PCI_CHIP_MGAG200_EH_PCI:
-	case PCI_CHIP_MGAG200_ER_PCI:
+    case PCI_CHIP_MGAG200_ER_PCI:
+    case PCI_CHIP_MGAG200_EH3_PCI:
     case PCI_CHIP_MGAG400:
     case PCI_CHIP_MGAG550:
 	MGAGSetupFuncs(pScrn);
@@ -443,7 +443,7 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
      * Setup the ClockRanges, which describe what clock ranges are available,
      * and what sort of modes they can be used for.
      */
-    clockRanges = xnfcalloc(sizeof(ClockRange), 1);
+    clockRanges = XNFcallocarray(sizeof(ClockRange), 1);
     clockRanges->next = NULL;
     clockRanges->minClock = pMga->MinClock;
     clockRanges->maxClock = pMga->MaxClock;
@@ -507,9 +507,11 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
 	case PCI_CHIP_MGAG200_SE_A_PCI:
 	case PCI_CHIP_MGAG200_SE_B_PCI:
         case PCI_CHIP_MGAG200_WINBOND_PCI:
+	case PCI_CHIP_MGAG200_EW3_PCI:		
         case PCI_CHIP_MGAG200_EV_PCI:
         case PCI_CHIP_MGAG200_EH_PCI:
 	case PCI_CHIP_MGAG200_ER_PCI:		
+	case PCI_CHIP_MGAG200_EH3_PCI:
 	case PCI_CHIP_MGAG400:
 	case PCI_CHIP_MGAG550:
 	   maxPitch = 4096;
@@ -673,10 +675,10 @@ InRegion(int x, int y, region r) {
         low += test-hi; \
         hi = test; } }
  void 
-MGAMergePointerMoved(int scrnIndex, int x, int y)
+MGAMergePointerMoved(SCRN_ARG_TYPE arg, int x, int y)
 {
-  ScrnInfoPtr   pScr = xf86Screens[scrnIndex];
-  MGAPtr        pMga = MGAPTR(pScr);
+  SCRN_INFO_PTR(arg);
+  MGAPtr        pMga = MGAPTR(pScrn);
   ScrnInfoPtr   pScr2 = pMga->pScrn2;
 
   region out,in1,in2,f2,f1;
@@ -695,18 +697,18 @@ MGAMergePointerMoved(int scrnIndex, int x, int y)
 
 
   /*specify outer clipping region. crossing this causes all frames to move*/
-  out.x0 = pScr->frameX0;
-  out.x1 = pScr->frameX1+1;
-  out.y0 = pScr->frameY0;
-  out.y1 = pScr->frameY1+1;
+  out.x0 = pScrn->frameX0;
+  out.x1 = pScrn->frameX1+1;
+  out.y0 = pScrn->frameY0;
+  out.y1 = pScrn->frameY1+1;
 
   /* 
-   * specify inner sliding window. beeing outsize both frames, and inside 
-   * the outer cliping window, causes corresponding frame to slide
+   * specify inner sliding window. being outsize both frames, and inside
+   * the outer clipping window, causes corresponding frame to slide
    */
   in1 = out;
   in2 = out;
-  switch(((MergedDisplayModePtr)pScr->currentMode->Private)->Monitor2Pos) {
+  switch(((MergedDisplayModePtr)pScrn->currentMode->Private)->Monitor2Pos) {
       case mgaLeftOf : 
           in1.x0 = f1.x0; 
           in2.x1 = f2.x1; 
@@ -754,8 +756,8 @@ MGAMergePointerMoved(int scrnIndex, int x, int y)
         f1.x1 += deltax;
         f2.x0 += deltax;
         f2.x1 += deltax;
-        pScr->frameX0 += deltax;
-        pScr->frameX1 += deltax;
+        pScrn->frameX0 += deltax;
+        pScrn->frameX1 += deltax;
         
 
         if ( out.y0 > y) { 
@@ -768,8 +770,8 @@ MGAMergePointerMoved(int scrnIndex, int x, int y)
         f1.y1 += deltay;
         f2.y0 += deltay;
         f2.y1 += deltay;
-        pScr->frameY0 += deltay;
-        pScr->frameY1 += deltay;
+        pScrn->frameY0 += deltay;
+        pScrn->frameY1 += deltay;
     } 
 
     
@@ -781,19 +783,19 @@ MGAMergePointerMoved(int scrnIndex, int x, int y)
         pScr2->frameY0 = f2.y0;
 
         /*Adjust Granularity */
-        MGAAdjustGranularity(pScr,&pMga->M1frameX0,&pMga->M1frameY0);
-        MGAAdjustGranularity(pScr,&pScr2->frameX0,&pScr2->frameY0);
-        MGAAdjustGranularity(pScr,&pScr->frameX0,&pScr->frameY0);
+        MGAAdjustGranularity(pScrn,&pMga->M1frameX0,&pMga->M1frameY0);
+        MGAAdjustGranularity(pScrn,&pScr2->frameX0,&pScr2->frameY0);
+        MGAAdjustGranularity(pScrn,&pScrn->frameX0,&pScrn->frameY0);
         
-        pMga->M1frameX1 = pMga->M1frameX0 + MDMPTR(pScr)->Monitor1->HDisplay -1;
-        pMga->M1frameY1 = pMga->M1frameY0 + MDMPTR(pScr)->Monitor1->VDisplay -1;
-        pScr2->frameX1 = pScr2->frameX0 + MDMPTR(pScr)->Monitor2->HDisplay -1;
-        pScr2->frameY1 = pScr2->frameY0 + MDMPTR(pScr)->Monitor2->VDisplay -1;
-        pScr->frameX1 = pScr->frameX0 + pScr->currentMode->HDisplay -1;
-        pScr->frameY1 = pScr->frameY0 + pScr->currentMode->VDisplay -1;
+        pMga->M1frameX1 = pMga->M1frameX0 + MDMPTR(pScrn)->Monitor1->HDisplay -1;
+        pMga->M1frameY1 = pMga->M1frameY0 + MDMPTR(pScrn)->Monitor1->VDisplay -1;
+        pScr2->frameX1 = pScr2->frameX0 + MDMPTR(pScrn)->Monitor2->HDisplay -1;
+        pScr2->frameY1 = pScr2->frameY0 + MDMPTR(pScrn)->Monitor2->VDisplay -1;
+        pScrn->frameX1 = pScrn->frameX0 + pScrn->currentMode->HDisplay -1;
+        pScrn->frameY1 = pScrn->frameY0 + pScrn->currentMode->VDisplay -1;
         
-        MGAAdjustFrame(pScr->scrnIndex, pMga->M1frameX0, pMga->M1frameY0, 0);
-        MGAAdjustFrameCrtc2(pScr->scrnIndex, pScr2->frameX0, pScr2->frameY0, 0);
+        MGAAdjustFrame(ADJUST_FRAME_ARGS(pScrn, pMga->M1frameX0, pMga->M1frameY0));
+        MGAAdjustFrameCrtc2(ADJUST_FRAME_ARGS(pScrn, pScr2->frameX0, pScr2->frameY0));
     }
 
 /*  if(pMga->PointerMoved)  
@@ -803,8 +805,9 @@ MGAMergePointerMoved(int scrnIndex, int x, int y)
 
    
 void
-MGAAdjustMergeFrames(int scrnIndex, int x, int y, int flags) {
-    ScrnInfoPtr pScrn1 = xf86Screens[scrnIndex];
+MGAAdjustMergeFrames(ADJUST_FRAME_ARGS_DECL) {
+    SCRN_INFO_PTR(arg);
+    ScrnInfoPtr pScrn1 = pScrn;
     MGAPtr pMga = MGAPTR(pScrn1); 
     ScrnInfoPtr pScrn2 = pMga->pScrn2;
     int VTotal = pScrn1->currentMode->VDisplay; 
@@ -846,7 +849,7 @@ MGAAdjustMergeFrames(int scrnIndex, int x, int y, int flags) {
             BOUND(pScrn2->frameY0,y,y + VMax - MDMPTR(pScrn1)->Monitor2->VDisplay);
             break;
     }
-    /* sanity checks. Make shure were not out of bounds */
+    /* sanity checks. Make sure were not out of bounds */
     BOUND(pMga->M1frameX0,0,pScrn1->virtualX -MDMPTR(pScrn1)->Monitor1->HDisplay);
     BOUND(pMga->M1frameY0,0,pScrn1->virtualY -MDMPTR(pScrn1)->Monitor1->VDisplay);
     BOUND(pScrn2->frameX0,0,pScrn2->virtualX -MDMPTR(pScrn1)->Monitor2->HDisplay);
@@ -868,14 +871,14 @@ MGAAdjustMergeFrames(int scrnIndex, int x, int y, int flags) {
     pScrn1->frameX1 = pScrn1->frameX0 + pScrn1->currentMode->HDisplay -1;
     pScrn1->frameY1 = pScrn1->frameY0 + pScrn1->currentMode->VDisplay -1;
 
-    MGAAdjustFrame(scrnIndex, pMga->M1frameX0, pMga->M1frameY0, flags);
-    MGAAdjustFrameCrtc2(scrnIndex, pScrn2->frameX0, pScrn2->frameY0, flags);
+    MGAAdjustFrame(ADJUST_FRAME_ARGS(pScrn, pMga->M1frameX0, pMga->M1frameY0));
+    MGAAdjustFrameCrtc2(ADJUST_FRAME_ARGS(pScrn, pScrn2->frameX0, pScrn2->frameY0));
     return;
 }
 
 Bool
-MGACloseScreenMerged(int scrnIndex, ScreenPtr pScreen) {
-    ScrnInfoPtr pScrn1 = xf86Screens[scrnIndex];
+MGACloseScreenMerged(ScreenPtr pScreen) {
+    ScrnInfoPtr pScrn1 = xf86ScreenToScrn(pScreen);
     MGAPtr pMga = MGAPTR(pScrn1); 
     ScrnInfoPtr pScrn2 = pMga->pScrn2;
 
@@ -906,7 +909,7 @@ MGACloseScreenMerged(int scrnIndex, ScreenPtr pScreen) {
 Bool
 MGASaveScreenMerged(ScreenPtr pScreen, int mode)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     MGAPtr pMga = MGAPTR(pScrn); 
     BOOL on = xf86IsUnblank(mode);
     CARD8 reg;
