@@ -5,7 +5,6 @@
 #include "xf86.h"
 #include "xf86_OSproc.h"
 #include "compiler.h"
-#include "xf86PciInfo.h"
 #include "xf86Pci.h"
 #include "xf86fbman.h"
 #include "regionstr.h"
@@ -15,12 +14,6 @@
 #include "mga_macros.h"
 #include "xf86xv.h"
 #include <X11/extensions/Xv.h>
-#include "xaa.h"
-
-#ifdef USE_XAA
-#include "xaa.h"
-#include "xaalocal.h"
-#endif
 
 #include "dixstruct.h"
 #include "fourcc.h"
@@ -73,7 +66,7 @@ static Atom xvBrightness, xvContrast, xvColorKey, xvDoubleBuffer;
 static void
 MGAVideoSave(ScreenPtr pScreen, ExaOffscreenArea *area)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     MGAPtr pMga = MGAPTR(pScrn);
     MGAPortPrivPtr pPriv = pMga->portPrivate;
 
@@ -84,7 +77,7 @@ MGAVideoSave(ScreenPtr pScreen, ExaOffscreenArea *area)
 
 void MGAInitVideo(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     XF86VideoAdaptorPtr *adaptors, *newAdaptors = NULL;
     XF86VideoAdaptorPtr newAdaptor = NULL;
     MGAPtr pMga = MGAPTR(pScrn);
@@ -131,8 +124,8 @@ void MGAInitVideo(ScreenPtr pScreen)
 	    num_adaptors = 1;
 	    adaptors = &newAdaptor;
 	} else {
-	    newAdaptors =  /* need to free this someplace */
-		xalloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr*));
+	    /* need to free this someplace */
+	    newAdaptors = malloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr *));
 	    if(newAdaptors) {
 		memcpy(newAdaptors, adaptors, num_adaptors * 
 					sizeof(XF86VideoAdaptorPtr));
@@ -146,8 +139,7 @@ void MGAInitVideo(ScreenPtr pScreen)
     if(num_adaptors)
         xf86XVScreenInit(pScreen, adaptors, num_adaptors);
 
-    if(newAdaptors)
-	xfree(newAdaptors);
+    free(newAdaptors);
 }
 
 /* client libraries expect an encoding */
@@ -231,10 +223,10 @@ MGAAllocAdaptor(ScrnInfoPtr pScrn, Bool doublebuffer)
     if(!(adapt = xf86XVAllocateVideoAdaptorRec(pScrn)))
 	return NULL;
 
-    if(!(pPriv = xcalloc(1, sizeof(MGAPortPrivRec) + 
+    if(!(pPriv = calloc(1, sizeof(MGAPortPrivRec) +
 			(sizeof(DevUnion) * MGA_MAX_PORTS)))) 
     {
-	xfree(adapt);
+	free(adapt);
 	return NULL;
     }
 
@@ -265,11 +257,13 @@ MGAAllocAdaptor(ScrnInfoPtr pScrn, Bool doublebuffer)
 static XF86VideoAdaptorPtr 
 MGASetupImageVideoOverlay(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     MGAPtr pMga = MGAPTR(pScrn);
     XF86VideoAdaptorPtr adapt;
 
     adapt = MGAAllocAdaptor(pScrn, TRUE);
+    if (adapt == NULL)
+	return NULL;
 
     adapt->type = XvWindowMask | XvInputMask | XvImageMask;
     adapt->flags = VIDEO_OVERLAID_IMAGES | VIDEO_CLIP_TO_VIEWPORT;
@@ -312,11 +306,13 @@ MGASetupImageVideoOverlay(ScreenPtr pScreen)
 static XF86VideoAdaptorPtr 
 MGASetupImageVideoTexture(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     XF86VideoAdaptorPtr adapt;
     MGAPtr pMga = MGAPTR(pScrn);
 
     adapt = MGAAllocAdaptor(pScrn, FALSE);
+    if (adapt == NULL)
+	return NULL;
 
     adapt->type = XvWindowMask | XvInputMask | XvImageMask;
     adapt->flags = 0;
@@ -564,11 +560,11 @@ MGAAllocateMemory(
    void **mem_struct,
    int size
 ){
-   MGAPtr pMga = MGAPTR(pScrn);
-   ScreenPtr pScreen = screenInfo.screens[pScrn->scrnIndex];
    int offset = 0;
 
 #ifdef USE_EXA
+   MGAPtr pMga = MGAPTR(pScrn);
+
    if (pMga->Exa) {
        ExaOffscreenArea *area = *mem_struct;
 
@@ -589,53 +585,6 @@ MGAAllocateMemory(
 	offset = area->offset;
    }
 #endif /* USE_EXA */
-#ifdef USE_XAA
-   FBLinearPtr linear = *mem_struct;
-   int cpp = pMga->CurrentLayout.bitsPerPixel / 8;
-
-   /* XAA allocates in units of pixels at the screen bpp, so adjust size
-    * appropriately.
-    */
-   size = (size + cpp - 1) / cpp;
-
-   if (!pMga->Exa) {
-       if (linear) {
-           if (linear->size >= size)
-               return linear->offset * cpp;
-
-           if (xf86ResizeOffscreenLinear(linear, size))
-               return linear->offset * cpp;
-
-           xf86FreeOffscreenLinear(linear);
-       }
-
-
-       linear = xf86AllocateOffscreenLinear(pScreen, size, 16,
-                                            NULL, NULL, NULL);
-       *mem_struct = linear;
-
-       if (!linear) {
-           int max_size;
-
-           xf86QueryLargestOffscreenLinear(pScreen, &max_size, 16,
-                                           PRIORITY_EXTREME);
-
-           if (max_size < size)
-               return 0;
-
-           xf86PurgeUnlockedOffscreenAreas(pScreen);
-
-           linear = xf86AllocateOffscreenLinear(pScreen, size, 16,
-                                                NULL, NULL, NULL);
-           *mem_struct = linear;
-
-           if (!linear)
-               return 0;
-       }
-
-       offset = linear->offset * cpp;
-   }
-#endif /* USE_XAA */
 
    return offset;
 }
@@ -643,9 +592,9 @@ MGAAllocateMemory(
 static void
 MGAFreeMemory(ScrnInfoPtr pScrn, void *mem_struct)
 {
+#ifdef USE_EXA
     MGAPtr pMga = MGAPTR(pScrn);
 
-#ifdef USE_EXA
     if (pMga->Exa) {
 	ExaOffscreenArea *area = mem_struct;
 
@@ -653,14 +602,6 @@ MGAFreeMemory(ScrnInfoPtr pScrn, void *mem_struct)
 	    exaOffscreenFree(pScrn->pScreen, area);
     }
 #endif /* USE_EXA */
-#ifdef USE_XAA
-    if (!pMga->Exa) {
-	FBLinearPtr linear = mem_struct;
-
-	if (linear)
-	    xf86FreeOffscreenLinear(linear);
-    }
-#endif /* USE_XAA */
 }
 
 static void
@@ -1082,18 +1023,18 @@ MGAAllocateSurface(
     surface->width = w;
     surface->height = h;
 
-    if(!(surface->pitches = xalloc(sizeof(int)))) {
+    if(!(surface->pitches = malloc(sizeof(int)))) {
         MGAFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
-    if(!(surface->offsets = xalloc(sizeof(int)))) {
-	xfree(surface->pitches);
+    if(!(surface->offsets = malloc(sizeof(int)))) {
+	free(surface->pitches);
         MGAFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
-    if(!(pPriv = xalloc(sizeof(OffscreenPrivRec)))) {
-	xfree(surface->pitches);
-	xfree(surface->offsets);
+    if(!(pPriv = malloc(sizeof(OffscreenPrivRec)))) {
+	free(surface->pitches);
+	free(surface->offsets);
         MGAFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
@@ -1137,9 +1078,9 @@ MGAFreeSurface(
     if(pPriv->isOn)
 	MGAStopSurface(surface);
     MGAFreeMemory(pScrn, pPriv->surface_memory);
-    xfree(surface->pitches);
-    xfree(surface->offsets);
-    xfree(surface->devPrivate.ptr);
+    free(surface->pitches);
+    free(surface->offsets);
+    free(surface->devPrivate.ptr);
 
     return Success;
 }
@@ -1225,13 +1166,13 @@ MGADisplaySurface(
 static void 
 MGAInitOffscreenImages(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     MGAPtr pMga = MGAPTR(pScrn);
     int num = (pMga->Chipset == PCI_CHIP_MGAG400 || pMga->Chipset == PCI_CHIP_MGAG550) ? 2 : 1;
     XF86OffscreenImagePtr offscreenImages;
 
     /* need to free this someplace */
-    if(!(offscreenImages = xalloc(num * sizeof(XF86OffscreenImageRec))))
+    if(!(offscreenImages = malloc(num * sizeof(XF86OffscreenImageRec))))
 	return;
 
     offscreenImages[0].image = &Images[0];
@@ -1294,11 +1235,13 @@ MGAInitOffscreenImages(ScreenPtr pScreen)
 static XF86VideoAdaptorPtr
 MGASetupImageVideoILOAD(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     XF86VideoAdaptorPtr adapt;
     MGAPtr pMga = MGAPTR(pScrn);
 
     adapt = MGAAllocAdaptor(pScrn, FALSE);
+    if (adapt == NULL)
+	return NULL;
 
     adapt->type = XvWindowMask | XvInputMask | XvImageMask;
     adapt->flags = 0;
@@ -1371,6 +1314,7 @@ static void CopyMungedScanline_AXP(CARD32 *fb_ptr, short src_w,
     }
 }
 
+#if 0
 static void CopyMungedScanline_AXP2(CARD32 *fb_ptr, short src_w,
 				    CARD32 *tsp, CARD32 *tpu, CARD32 *tpv)
 {
@@ -1390,6 +1334,7 @@ static void CopyMungedScanline_AXP2(CARD32 *fb_ptr, short src_w,
 	fb_ptr+=4;
     }
 }
+#endif
 
 
 static void CopyMungedScanlineFilter_AXP(CARD32 *fb_ptr, short src_w,
@@ -1463,6 +1408,7 @@ static void CopyMungedScanlineFilter_AXP(CARD32 *fb_ptr, short src_w,
     }
 }
 
+#if 0
 static void CopyMungedScanlineFilterDown_AXP(CARD32 *fb_ptr, short src_w,
 					     CARD32 *tsp1, CARD32 *tpu1, CARD32 *tpv1,
 					     CARD32 *tsp2, CARD32 *tpu2, CARD32 *tpv2,
@@ -1501,6 +1447,7 @@ static void CopyMungedScanlineFilterDown_AXP(CARD32 *fb_ptr, short src_w,
 	fb_ptr+=4;
     }
 }
+#endif
 
 static void MGACopyScaledILOAD(
 			       ScrnInfoPtr pScrn,
@@ -1517,7 +1464,12 @@ static void MGACopyScaledILOAD(
     CARD32 *fb_ptr;
     unsigned char *ubuf, *vbuf, *tbuf;
     CARD32 *pu, *pv;
-    int k,l, pl, dl, xds, yds;
+    int k,l;
+#ifdef MGA2164_BLIT_DUP
+    int pl;
+#endif /* MGA2164_BLIT_DUP */
+    int dl;
+    int xds, yds;
     short box_h;
     short scr_pitch = ( pScrn->virtualX + 15) & ~15;
 
@@ -1603,8 +1555,10 @@ static void MGACopyScaledILOAD(
     ubuf=vbuf+width*height/4;
     pu = (CARD32 *)(ubuf+(src_y/2)*(width/2));
     pv = (CARD32 *)(vbuf+(src_y/2)*(width/2));
-
-    for(pl=-1,dl=0;dl<box_h;dl++) {
+#ifdef MGA2164_BLIT_DUP
+    pl = -1;
+#endif /* MGA2164_BLIT_DUP */
+    for(dl=0;dl<box_h;dl++) {
 	int beta;
 	l=(dl+(pbox->y1-drw_y))*src_h/drw_h;
 	/* FIXME: check the math */
@@ -1761,7 +1715,9 @@ static void MGACopyScaledILOAD(
 		    default:
 			break;
 		    }
+#ifdef MGA2164_BLIT_DUP
 		    pl=l;
+#endif /* MGA2164_BLIT_DUP */
 		} else {
 		    /* dup lines */
 
@@ -1798,7 +1754,10 @@ static void MGACopyILOAD(
     CARD32 *fb_ptr;
     CARD8  *ubuf, *vbuf;
     CARD32 *pu, *pv;
-    int k,l;
+#ifdef CUSTOM_MEMCOPY
+    int k;
+#endif /* CUSTOM_MEMCOPY */
+    int l;
     short clip_x1, clip_x2, tmp_w;
 
 #ifdef DEBUG_MGA2164
@@ -1965,7 +1924,6 @@ MGAPutImageILOAD(
     MGAPortPrivPtr pPriv = pMga->portPrivate;
     INT32 x1, x2, y1, y2;
     int dstPitch = 0;
-    int bpp;
     BoxRec dstBox;
     int nbox;
     BoxPtr pbox;
@@ -1981,12 +1939,6 @@ MGAPutImageILOAD(
 			      clipBoxes, width, height))
 	return Success;
 
-    bpp = pScrn->bitsPerPixel >> 3;
-
-    if( pMga->AccelInfoRec->NeedToSync && ((long)data != pPriv->lastPort) ) {
-	MGAStormSync(pScrn);
-    }
-
     pPriv->lastPort = (long)data;
     nbox=REGION_NUM_RECTS(clipBoxes);
     pbox=REGION_RECTS(clipBoxes);
@@ -2015,8 +1967,6 @@ MGAPutImageILOAD(
 	pbox++;
     }
 
-
-    pMga->AccelInfoRec->NeedToSync = TRUE;
     pPriv->videoStatus = FREE_TIMER;
     pPriv->freeTime = currentTime.milliseconds + FREE_DELAY;
     pMga->VideoTimerCallback = MGAVideoTimerCallback;
